#[non_exhaustive]pub enum ColorSpace {
Undefined,
YCbCr(Chroma),
Rgb(RgbChroma),
Monochrome,
NonVisual,
Custom,
FilterArray,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Undefined
YCbCr(Chroma)
Rgb(RgbChroma)
Monochrome
NonVisual
👎Deprecated since 2.8.0:
use ColorSpace::Custom instead.
Available on crate feature
v1_19 only.Indicates that this image has a special, custom arrangement of components. For example, it can have several monochrome channels or just a depth component with no color image. Images of this type are always planar.
Custom
Available on crate feature
v1_23 only.Indicates that this image has a special, custom arrangement of components. For example, it can have several monochrome channels or just a depth component with no color image. Images of this type are always planar.
FilterArray
Available on crate feature
v1_23 only.Images of this type are filter-array (CFA / Bayer) mosaics. The single mosaicked plane is described as Monochrome.